From c35cd422c65a58f1069302aad0cf9eef7f93d987 Mon Sep 17 00:00:00 2001
From: Ben Schlegel <31989404+benschlegel@users.noreply.github.com>
Date: Mon, 28 Aug 2023 17:00:49 +0000
Subject: [PATCH] fix: correct graph labels for `index.md` nodes (#431)

---
 quartz/plugins/emitters/componentResources.ts |  121 ++++++++++++++++++++++++++-------------
 1 files changed, 80 insertions(+), 41 deletions(-)

diff --git a/quartz/plugins/emitters/componentResources.ts b/quartz/plugins/emitters/componentResources.ts
index bc1d4ab..c52a3a2 100644
--- a/quartz/plugins/emitters/componentResources.ts
+++ b/quartz/plugins/emitters/componentResources.ts
@@ -1,5 +1,5 @@
-import { FilePath, ServerSlug } from "../../path"
-import { PluginTypes, QuartzEmitterPlugin } from "../types"
+import { FilePath, FullSlug } from "../../util/path"
+import { QuartzEmitterPlugin } from "../types"
 
 // @ts-ignore
 import spaRouterScript from "../../components/scripts/spa.inline"
@@ -9,10 +9,11 @@
 import popoverScript from "../../components/scripts/popover.inline"
 import styles from "../../styles/base.scss"
 import popoverStyle from "../../components/styles/popover.scss"
-import { BuildCtx } from "../../ctx"
-import { StaticResources } from "../../resources"
+import { BuildCtx } from "../../util/ctx"
+import { StaticResources } from "../../util/resources"
 import { QuartzComponent } from "../../components/types"
-import { googleFontHref, joinStyles } from "../../theme"
+import { googleFontHref, joinStyles } from "../../util/theme"
+import { Features, transform } from "lightningcss"
 
 type ComponentResources = {
   css: string[]
@@ -67,7 +68,6 @@
 ) {
   const cfg = ctx.cfg.configuration
   const reloadScript = ctx.argv.serve
-  staticResources.css.push(googleFontHref(cfg.theme))
 
   // popovers
   if (cfg.enablePopovers) {
@@ -98,57 +98,96 @@
     componentResources.afterDOMLoaded.push(plausibleScript)
   }
 
-  // spa
   if (cfg.enableSPA) {
     componentResources.afterDOMLoaded.push(spaRouterScript)
   } else {
     componentResources.afterDOMLoaded.push(`
         window.spaNavigate = (url, _) => window.location.assign(url)
-        const event = new CustomEvent("nav", { detail: { slug: document.body.dataset.slug } })
+        const event = new CustomEvent("nav", { detail: { url: document.body.dataset.slug } })
         document.dispatchEvent(event)`)
   }
 
+  let wsUrl = `ws://localhost:${ctx.argv.wsPort}`
+
+  if (ctx.argv.remoteDevHost) {
+    wsUrl = `wss://${ctx.argv.remoteDevHost}:${ctx.argv.wsPort}`
+  }
+
   if (reloadScript) {
     staticResources.js.push({
       loadTime: "afterDOMReady",
       contentType: "inline",
       script: `
-          const socket = new WebSocket('ws://localhost:3001')
+          const socket = new WebSocket('${wsUrl}')
           socket.addEventListener('message', () => document.location.reload())
         `,
     })
   }
 }
 
-export const ComponentResources: QuartzEmitterPlugin = () => ({
-  name: "ComponentResources",
-  getQuartzComponents() {
-    return []
-  },
-  async emit(ctx, _content, resources, emit): Promise<FilePath[]> {
-    // component specific scripts and styles
-    const componentResources = getComponentResources(ctx)
-    // important that this goes *after* component scripts
-    // as the "nav" event gets triggered here and we should make sure
-    // that everyone else had the chance to register a listener for it
-    addGlobalPageResources(ctx, resources, componentResources)
-    const fps = await Promise.all([
-      emit({
-        slug: "index" as ServerSlug,
-        ext: ".css",
-        content: joinStyles(ctx.cfg.configuration.theme, styles, ...componentResources.css),
-      }),
-      emit({
-        slug: "prescript" as ServerSlug,
-        ext: ".js",
-        content: joinScripts(componentResources.beforeDOMLoaded),
-      }),
-      emit({
-        slug: "postscript" as ServerSlug,
-        ext: ".js",
-        content: joinScripts(componentResources.afterDOMLoaded),
-      }),
-    ])
-    return fps
-  },
-})
+interface Options {
+  fontOrigin: "googleFonts" | "local"
+}
+
+const defaultOptions: Options = {
+  fontOrigin: "googleFonts",
+}
+
+export const ComponentResources: QuartzEmitterPlugin<Options> = (opts?: Partial<Options>) => {
+  const { fontOrigin } = { ...defaultOptions, ...opts }
+  return {
+    name: "ComponentResources",
+    getQuartzComponents() {
+      return []
+    },
+    async emit(ctx, _content, resources, emit): Promise<FilePath[]> {
+      // component specific scripts and styles
+      const componentResources = getComponentResources(ctx)
+      // important that this goes *after* component scripts
+      // as the "nav" event gets triggered here and we should make sure
+      // that everyone else had the chance to register a listener for it
+
+      if (fontOrigin === "googleFonts") {
+        resources.css.push(googleFontHref(ctx.cfg.configuration.theme))
+      } else if (fontOrigin === "local") {
+        // let the user do it themselves in css
+      }
+
+      addGlobalPageResources(ctx, resources, componentResources)
+
+      const stylesheet = joinStyles(ctx.cfg.configuration.theme, styles, ...componentResources.css)
+      const prescript = joinScripts(componentResources.beforeDOMLoaded)
+      const postscript = joinScripts(componentResources.afterDOMLoaded)
+      const fps = await Promise.all([
+        emit({
+          slug: "index" as FullSlug,
+          ext: ".css",
+          content: transform({
+            filename: "index.css",
+            code: Buffer.from(stylesheet),
+            minify: true,
+            targets: {
+              safari: (15 << 16) | (6 << 8), // 15.6
+              ios_saf: (15 << 16) | (6 << 8), // 15.6
+              edge: 115 << 16,
+              firefox: 102 << 16,
+              chrome: 109 << 16,
+            },
+            include: Features.MediaQueries,
+          }).code.toString(),
+        }),
+        emit({
+          slug: "prescript" as FullSlug,
+          ext: ".js",
+          content: prescript,
+        }),
+        emit({
+          slug: "postscript" as FullSlug,
+          ext: ".js",
+          content: postscript,
+        }),
+      ])
+      return fps
+    },
+  }
+}

--
Gitblit v1.10.0